@@ -43,6 +43,55 @@ def ps_lensed_theory_to_dict(filename, output_type, lmax=None, start_at_zero=Fal
     return l, ps
 
 
+
+def ps_from_params(cosmo_params, output_type, lmax, start_at_zero=False):
+
+    """Given a set of cosmological parameters compute the corresponding lensed power spectrum
+       You need to have camb installed to use this function
+      ----------
+      cosmo_params: dict
+        dictionnary of cosmological parameters
+        # e.g cosmo_params = {"cosmomc_theta":0.0104085, "logA": 3.044, "ombh2": 0.02237, "omch2": 0.1200, "ns": 0.9649, "Alens": 1.0, "tau": 0.0544}
+      output_type :  string
+        'Cl' or 'Dl'
+      lmax: integer
+        the maximum multipole to consider
+      start_at_zero : boolean
+        if True, ps start at l=0 and cl(l=0) and cl(l=1) are set to 0
+        else, start at l=2
+    """
+    try:
+        import camb
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError("you need to install camb to use this function")
+
+    if start_at_zero:
+        lmin = 0
+    else:
+        lmin = 2
+        
+    camb_cosmo = {k: v for k, v in cosmo_params.items() if k not in ["logA", "As"]}
+    camb_cosmo.update({"As": 1e-10*np.exp(cosmo_params["logA"]), "lmax": lmax, "lens_potential_accuracy": 1})
+    pars = camb.set_params(**camb_cosmo)
+    results = camb.get_results(pars)
+    powers = results.get_cmb_power_spectra(pars, CMB_unit="muK")
+    l = np.arange(lmin, lmax)
+    ps = {spec: powers["total"][l][:, count] for count, spec in enumerate(["TT", "EE", "BB", "TE" ])}
+    ps["ET"] = ps["TE"]
+    for spec in ["TB", "BT", "EB", "BE" ]:
+        ps[spec] = ps["TT"] * 0
+    
+    scale = l * (l + 1) / (2 * np.pi)
+    if output_type == "Cl":
+        if start_at_zero:
+            ps[2:] /= scale[2:]
+        else:
+            ps[:] /= scale[:]
+
+    return l, ps
+    
+    
+
 def get_nlth_dict(rms_uKarcmin_T, type, lmax, spectra=None, rms_uKarcmin_pol=None, beamfile=None):
     """Return the effective noise power spectrum Nl/bl^2 given a beam file and a noise rms
 
@@ -81,9 +130,9 @@ def get_nlth_dict(rms_uKarcmin_T, type, lmax, spectra=None, rms_uKarcmin_pol=Non
             rms_uKarcmin_pol = rms_uKarcmin_T * np.sqrt(2)
         for spec in spectra:
             nl_th[spec] = np.zeros(lmax)
-        nl_th["TT"] = np.ones(lmax) * (rms_uKarcmin_T * np.pi / (60 * 180)) ** 2 / bl[:lmax] ** 2
-        nl_th["EE"] = np.ones(lmax) * (rms_uKarcmin_pol * np.pi / (60 * 180)) ** 2 / bl[:lmax] ** 2
-        nl_th["BB"] = np.ones(lmax) * (rms_uKarcmin_pol * np.pi / (60 * 180)) ** 2 / bl[:lmax] ** 2
+        nl_th["TT"] = np.ones(lmax) * (rms_uKarcmin_T * np.pi / (60 * 180)) ** 2 / bl[2 :lmax + 2] ** 2
+        nl_th["EE"] = np.ones(lmax) * (rms_uKarcmin_pol * np.pi / (60 * 180)) ** 2 / bl[2 :lmax + 2] ** 2
+        nl_th["BB"] = np.ones(lmax) * (rms_uKarcmin_pol * np.pi / (60 * 180)) ** 2 / bl[2 :lmax + 2] ** 2
         if type == "Dl":
             for spec in spectra:
                 nl_th[spec] *= lth * (lth + 1) / (2 * np.pi)
@@ -217,3 +266,5 @@ def beam_from_fwhm(fwhm_arcminute, lmax):
     ell = np.arange(2, lmax)
     bl = np.exp(-ell * (ell + 1) * fac ** 2 / 2.0)
     return ell, bl
+
+
